@@ -38,7 +38,6 @@ DDockMenu::DDockMenu(DDockMenu *parent)
     , m_menuContent(new DMenuContent(this))
     , m_monitor(new DRegionMonitor(this))
 {
-    setWindowFlags(Qt::FramelessWindowHint | Qt::Tool);
     setAttribute(Qt::WA_InputMethodEnabled, false);
 
     setMouseTracking(true);
@@ -149,6 +148,10 @@ bool DDockMenu::event(QEvent *event)
         }
     }
 
+    if (event->type() == QEvent::Move) {
+        qDebug() << pos();
+    }
+
     return DArrowRectangle::event(event);
 }
 
