@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
+ * Copyright (C) 2015 ~ 2018 Deepin Technology Co., Ltd.
  *
  * Author:     Hualet Wang <mr.asianwang@gmail.com
  *
@@ -22,8 +22,6 @@
 
 #include <QObject>
 #include <QStringList>
-#include <xcb/xcb.h>
-#include <xcb/xproto.h>
 
 #define DISPLAY_SERVICE "com.deepin.daemon.Display"
 #define DISPLAY_PATH "/com/deepin/daemon/Display"
@@ -31,21 +29,12 @@
 #define DISPLAY_INTERFACE "com.deepin.daemon.Display"
 #define MONITOR_INTERFACE "com.deepin.daemon.Display.Monitor"
 
-class QX11Info;
 class QString;
-class QPoint;
-class QRect;
 
 namespace Utils {
 
 bool menuItemCheckableFromId(QString id);
 
-void grabKeyboard(xcb_window_t);
-void grabPointer(xcb_window_t);
-
-bool pointInRect(QPoint, QRect);
-QRect currentMonitorRect(int, int);
-
 }
 
 #endif // UTILS_H
